
//***********************************************************************************//
/************ El microcontrolador utilizado es el PIC16F676 **************************/
/*************************************************************************************/

/*************************** Detalle de conexiones ***********************************/


//                          ----------     ---------
//                   VDD  -| 1        \___/       14|-  GND 
// Int/Ext Adaptador A/C  -| 2 A5              A0 13|-  Habilitar carga batera
//                        -| 3 A4      PIC     A1 12|- 
//                        -| 4 A3    16F676    A2 11|-
//              Led Rojo  -| 5 C5              C0 10|-  Tensin batera (A/D)
//             Led Verde  -| 6 C4              C1  9|-
//      Temperatura(A/D)  -| 7 C3              C2  8|-  Buzzer
//                          ------------------------                   



/*************************************************************************************/
/******************************* Carga de baterias por tiempo ************************/
/*************************************************************************************/
/* Se interrumpe el proceso de carga por: Tiempo, dV/dt, Tensin mxima, Temperatura */
/*************************************************************************************/
/*************************************************************************************/


#include <16F676.h>                    // Librera
#device ADC=10;
#FUSES INTRC_IO,NOWDT,NOPROTECT,PUT    // Ordenes para el programador
#FUSES NOMCLR                          // Master Clear pin disable********
#use delay (clock=4000000)             // Fosc=4Mhz
#define VSS-VDD                        // Range 0-Vdd
#use fast_io(a)

#bit RA0=0x05.0
#bit RA1=0x05.1
#bit RA2=0x05.2
#bit RA3=0x05.3
#bit RA4=0x05.4
#bit RA5=0x05.5
#bit RC0=0x07.0
#bit RC1=0x07.1
#bit RC2=0x07.2
#bit RC3=0x07.3
#bit RC4=0x07.4
#bit RC5=0x07.5

int x=0,t=0;
int interrup,tiempo=0,fin_carga=0,contador=0,peligro=0;
long tension_desc,tension_min=321, tension_umbral=310;                // tensin minima 6.6V (acciona buzzer y led)
                                                                      // tensin umbral 6.3V (desconecta la bateria del tablero)
long tension_bat_2=0,tension_bat_1,tension_max=399,resta,dif_max=46;  // tensin maxima 0x0206= 8,4V
long temp_max=78, temperatura;                                        //temperatura maxima que puede alcanzar 38C

long banderatimer=0, banderatimer2=0,banderatimer3=0, bandera_seg=15, bandera_minut=225, bandera_hora=100;   // 1 segundo --------- 15 bandera_seg
                                                                                                             
                                                                                                             // 222 segundos ------ 1 bandera_hora
int tiempo_interrup=0,fin=1;                                                                                 // 6hs 10min---------- 100 bandera_hora
                                                                                                             //*** "Tiempo De Corte de Carga= 6hs 10 min" ***//
long alarma_descarga(long tension_desc);            
void testeo_carga(void);
void led_carga(void);
void testeo_temp(void);
void contador_timer(void);

///////********************** Interrupciones *********************************************////////
///////***********************************************************************************////////


#INT_RA             
void A5(void)
 {
if(RA5)          
   {
    interrup=0;   // bandera de adaptador AC no esta conectado
     
   if((tension_desc >= tension_umbral)&&(input(pin_A5)==1)) output_low(pin_A0); 
   }
  else{interrup=1;
       if(input(pin_A5)==1) output_low(pin_A0);
       if(input(pin_A5)==0) output_high(pin_A0); 
       }
    
   return;
 }

//////*************************************************************************************//////

 #int_timer0
void timer0_isr(void)
{ banderatimer++;
  if(banderatimer==bandera_seg)
    { banderatimer2++;         
      if(banderatimer2==bandera_minut){ banderatimer3++; 
                                        if(banderatimer3==bandera_hora){
                                                                       disable_interrupts(INT_TIMER0);
                                                                       disable_interrupts(GLOBAL);
                                                                       banderatimer3=0;
                                                                       fin=0;
                                                                        tiempo_interrup=3;
                                                                       }
                                      tiempo_interrup=2;
                                      banderatimer2=0;
                                      }
      banderatimer=0;
      if(tiempo_interrup!=2) tiempo_interrup=1;
    }
 return;
 } 
 
/*********** Nota: el clock para el Timer0 es clk/4. Ver datasheet del pic. ********************/
//**********************************************************************************************/ 
 
 
 setup_oscillator(OSC_4Mhz);       //seteo el oscilador a 4Mhz
 
   /////////////////////////******************************************//////////////////////////////
   /////////////////////////**********  Programa Principal   *********//////////////////////////////
   /////////////////////////*****************************************///////////////////////////////
   /////////////////////////*****************************************///////////////////////////////

void main()
 {  set_tris_c(0b11001011);      // **************** seteo RC 2/4/5 como salidas *****
    set_tris_a(0b11111110);      // *****************seteo RA 0 como salidas *********
    
    output_low(pin_C2);          // apago el buzzer al comenzar
    output_low(pin_C4);          //  apago los leds
    output_low(pin_C5);          // 
    
    if(input(pin_A5)==1) output_low(pin_A0); 
    if(input(pin_A5)==0) output_high(pin_A0);    
    
    enable_interrupts (INT_EXT);
    enable_interrupts (INT_RA5);
    enable_interrupts (GLOBAL);
    EXT_INT_EDGE(H_TO_L);
    interrup=0;                       //punto de prueba; no esta conectado el adaptador AC
    if(input(pin_A5)==0) interrup=1;
    
    while(true)
    {
     output_low(pin_C4);          //*** apago los leds
     output_low(pin_C5);          //***************** 
     
     tension_bat_2=0;  // inicializa la variable de la carga
     contador=0;
/////////////////////////////////////  Etapa de Descarga  ///////////////////////////////////////

    while(interrup==0) // si no esta conectado, entro y utilizo la funcion de tension de descarga
      {  
         
         setup_adc(ADC_Clock_DIV_8);   ///////////agregado 
         setup_adc_ports(ALL_ANALOG);
         set_adc_channel(4);
         delay_ms(50);
         tension_desc=read_adc();
         delay_ms(50);
         setup_adc( ADC_OFF );     
         delay_ms(200);
         output_low(pin_C4);                     //apago led verde   
        
         enable_interrupts (INT_EXT);
         enable_interrupts (INT_RA5);
         enable_interrupts (GLOBAL);
         EXT_INT_EDGE(L_TO_H);
          if(input(pin_A5)==1)
               {output_low(pin_A0);
                output_low(pin_A0);
               }
         if(input(pin_A5)==0) {led_carga();      
                                interrup=1;
                              }
       peligro=0;
       while((tension_desc <= tension_min)&&(interrup==0))
            {
             tension_desc=alarma_descarga(tension_desc);
             if((input(pin_A5)==0)&&(peligro==0))
               {output_high(pin_A0);
                output_high(pin_A0);
               }
            if((input(pin_A5)==1)&&(peligro==0))
               {output_low(pin_A0);
                output_low(pin_A0);
               }
            }
      }
 ///////////////////////////////////////////////////////////////////////////////////////////
  
    tension_bat_2=0;  // inicializa la variable de la carga
    contador=0; 
    resta=0;
    fin=1;

//////////////////////////////////  Etapa de carga  ///////////////////////////////////////
 
    while((interrup==1)&&(input(pin_A5)==0)) // adaptador de carga conectado.
      { 
       contador_timer();  // setea el timer 0, con esta funcion cuento las 6hs
       t++; 
       if(t==20) testeo_carga(); //***** Testeo de funcion de carga
             
       if(t>=20) t=0;           //t=20 significa 20 x 2segundos=40seg de espera para evitar fluctuaciones
       led_carga();
       testeo_temp();  //***********************  Testeo de funcion temperatura
      }


    if((tension_desc >= tension_umbral)&&(input(pin_A5)==1))   //esto indica que el adaptador esta desconectado y tension bateria es mayor umbral
                          { output_low(pin_A0);                // conecta bateria al tablero.
                            enable_interrupts (INT_EXT);
                            enable_interrupts (GLOBAL);
                          }
    } 
 }

 ///////////////////////***********************************************////////////////////
 ///////////////////////***************  Funciones ********************////////////////////
 ///////////////////////***********************************************////////////////////


//////*********************** Testeo de tensin de descarga ************************///////
//////******************************************************************************///////

long alarma_descarga(long tension_desc)          // (la tensin de la bateria no debe caer por debejo de 6,4V)
 {
  if(tension_desc <= tension_umbral){   output_high(pin_A0);     //cambio posicion de relay (desconecto bateria de tablero)
                                        peligro=1;
                                    }
  if(interrup==0)
      {tiempo++;
       output_high(pin_C5);                     //acciono led rojo
         if(tiempo==20) {output_high(pin_C2);   //acciono buzzer
                         delay_ms(2000);
                         }
       delay_ms(200);
       output_low(pin_C5);                     //apago led rojo
         if(tiempo==20){delay_ms(100);
                         output_low(pin_C2);   //apago buzzer
                         tiempo=0;
                         }
         delay_ms(200);
         setup_adc(ADC_Clock_DIV_8);   ///////////agregado 
         setup_adc_ports(ALL_ANALOG);
         set_adc_channel(4);
         delay_ms(50);
         tension_desc=read_adc();       // lee el valor de tension de la bateria
         delay_ms(50);
         setup_adc( ADC_OFF );     
         delay_ms(200);
         return(tension_desc);
      }
 }


//////***********************  Testeo de funcion de carga ---> dv/dt + tensin max   *******///////
//////**************************************************************************************///////

 void testeo_carga(void)
 {  setup_adc(ADC_Clock_DIV_8);   ///////////agregado 
    setup_adc_ports(ALL_ANALOG);
    set_adc_channel(4);
    delay_ms(2000);               // este delay es para evitar las fluctuaciones en la carga (2 segundos)
    fin_carga=0;
    tension_bat_1=read_adc();  
    delay_ms(50);
    setup_adc( ADC_OFF );
    tension_desc=tension_bat_1;
   if(tension_bat_1 + 5 >= tension_bat_2)  //entra si la pendiente es positiva y derivada
      { resta=tension_bat_1-tension_bat_2;
        if((resta>=dif_max)&&(contador!=0))
                           {                        //abrir el circuito de carga 
                           output_low(pin_A0);      //***revisar el valor de la pendiente (0x00CC es 1V)                  
                           }
       tension_bat_2=tension_bat_1;
       contador=contador+1;
       //fin_carga=0;
      }
      else{tension_bat_2=0;  // inicializa la variable de la carga
           contador=0; 
           resta=0;
           output_high(pin_A0); // habilita l carga de bateria
           fin_carga=0;
           }
   if(tension_bat_1>=tension_max)   //corte de carga por tension maxima
      {
        output_low(pin_A0);  //abrir el circuito de carga***
        fin_carga=1;
       }
   return;
  }
 
///////************************** prende los leds *************************************//////
///////********************************************************************************//////

 void led_carga()
 {
  output_low(pin_C4);
 
 if(fin_carga==0)
      {output_high(pin_C4);                  //acciono led verde
       delay_ms(700);
       output_low(pin_C4);                   //apago led verde
       delay_ms(700);
       x=0;
      }
 if(fin_carga==1)
      {output_high(pin_C4);                  //acciono led verde_ CARGA COMPLETA
       delay_ms(700);
       output_low(pin_A0);
         while(x<=3)                      // alarma de buzzer
           {output_high(pin_C2);          //
            delay_ms(200);                //
            output_low(pin_C2);           //
            delay_ms(400);                //
            x++;                          //
           }
       }
  return; 
 }
 
///////******************** Testeo de funcion temperatura ******************************///////
///////*********************************************************************************///////

 void testeo_temp()
 {
     setup_adc(ADC_Clock_DIV_8);   ///////////agregado 
     setup_adc_ports(ALL_ANALOG);
     set_adc_channel(7);
     delay_ms(20); 
     temperatura=read_adc();
     delay_ms(50);
     setup_adc( ADC_OFF );
   if((temperatura >= temp_max)&&(fin_carga==0)) {output_low(pin_A0);  //esto hace que no supere los 40C
                                                  contador=0;        // evita que las fluctuaciones afecten la carga normal
                                                  tension_bat_2=0;   // inicializa la variable de la carga
                                                  }
   if((temperatura < temp_max)&&(fin_carga==0)) output_high(pin_A0);
  return;
 }
 
///////*************************** Contador para Timer ***********************************///////
///////***********************************************************************************///////

 void contador_timer()
 {
    setup_timer_0(RTCC_INTERNAL|RTCC_DIV_256);
    enable_interrupts(INT_TIMER0);
    enable_interrupts(GLOBAL);
  
 if(fin==0){disable_interrupts(INT_TIMER0);
            disable_interrupts(GLOBAL);
            banderatimer3=0;
            banderatimer2=0;
            banderatimer=0;
            output_low(pin_A0); // abrir el relay de carga de bateria
            fin_carga=1;
           }
   return;
 }
