//****************************************************************************//
/************ El microcontrolador utilizado es el PIC18F2520 ******************/
/******************************************************************************/

/*************************** Detalle de conexiones ****************************/


//                          ----------     ---------
//                        -| 1 MCLR   \___/    B7 28|- Pin6 (IC4)
//                 Fila 1 -| 2 A0              B6 27|- Pin2 (IC4)
//                 Fila 2 -| 3 A1     PIC      B5 26|- Pin1 (IC4)
//                 Fila 3 -| 4 A2   18F2520    B4 25|- Pin7 (IC4)
//              Columna 4 -| 5 A3              B3 24|- 
//              Columna 3 -| 6 A4              B2 23|- Velocidad
//              Columna 2 -| 7 A5              B1 22|- Barrido
//                    GND -| 8                 B0 21|- Switch
//              Columna 1 -| 9 A7                 20|- VDD
//            Leds Alarma -|10 A6                 19|- GND
//                 Buzzer -|11 C0              C7 18|- RX 
//                        -|12 C1              C6 17|- TX 
//             Pin7 (IC2) -|13 C2              C5 16|- Pin6 (IC2)
//             Pin1 (IC2) -|14 C3              C4 15|- Pin2 (IC2)
//                          ------------------------
//
/*------------------------------------------------------------------------------
    * Los pines rotulados como Filas y Columnas constituyen la matriz de leds
    * C2,C3,C4.C5 display configuracin velocidad
    * B4,B5,B6,B7 display configuracin barrido
/*------------------------------------------------------------------------------

/******************************************************************************/


#include <18F2520.h>                     // pic a utilizar
#fuses INTRC_IO,NOWDT,NOPROTECT,PUT      // ordenes para el programador
#FUSES NOMCLR                            // Master Clear pin disable********
#use delay (clock=4000000)               // Fosc=4Mhz
#use fast_io(b)                          // 

#byte  PORT_B = 6
#bit RB0=0x06.0
#bit RB1=0x06.1
#bit RB7=0x06.7
#bit RB2=0x06.2         //nuevo
#bit RB3=0x06.3         //nuevo

#define NUM_TECLADO 20
#define NUM_VELOC   25
#define EECON1      0xFA6    //posicion de memoria del registro
#define WREN      2          // valor de la variable

//*********************  Declaracin de funciones *****************************//

void inic_memoria(void);
void modo_lectura(int i1);            //barrido automatico
void modo_lectura2(int i3);           //barrido manual 
void modo_circular(int i2);           //barrido automatico
void modo_circular2(int i5);          //barrido manual
void modo_circular_esq(int i3);
void modo_lectura_esq(int i4);
void modo_dos_tarjetas(int i6);
void display(int x);
void display2(int x2);
void barrido(int y);
int velocidad(int y2);
void retardo(int z);
int reloj(int w);
void alarma(int v);
void alarma_2(int v2);
void apago_todo(void);

//******************** Declaracin de variables ********************************//

int teclado=0,tarjeta=0,tarjeta1=0,salir=0,cont_displ=0,cont_modo=0,cont_displ2=0,cont_modo2=0,banderatimer=0;
int veloc,veloc1=0,saltar=0,saltar1=0,salir2=0,bandera,tiempo=0,reconocer=0;
int stop=0,reinicio=0;
long dormir=0;

//******************** Definicin de interrupciones **************************// 

//******************** Interrupcin de switch ********************************//
#int_EXT
void EXT0(void)
{
if(RB0==0){if(reconocer==1) stop=1; delay_ms(100);}  // 
do{       
     delay_ms(100);
     }while(input(pin_B0)==0);

if(tarjeta==1) delay_ms(200);
if (input(pin_B0)==1)
 {
// delay_ms(50);
 if ((input(pin_B0)==1)&&(reinicio==0))
   {                           // salidas port c
       
     if(teclado==1){if(reconocer==1) stop=1; 
                    reconocer=1;dormir=0;tarjeta1=tarjeta;           //lo realice para el sleep
                   }
     if(teclado==2){if(reconocer==1) stop=1; 
                    reconocer=1;dormir=0;tarjeta1=tarjeta;           //lo realice para el sleep
                   }
     if(teclado==3){if(reconocer==1) stop=1; 
                    reconocer=1;dormir=0;tarjeta1=tarjeta;           //lo realice para el sleep
                   }
     if(teclado==4){if(reconocer==1) stop=1; 
                    reconocer=1;dormir=0;tarjeta1=tarjeta;           //lo realice para el sleep
                   }
     if(teclado==9){if(reconocer==1) stop=1; 
                    reconocer=1;dormir=0;tarjeta1=tarjeta;           //lo realice para el sleep
                   }
     if(teclado==5){  delay_ms(90);dormir=0;
                      banderatimer=0;
                      bandera=reloj(veloc);
                      veloc1=veloc1+1;
                      tiempo=1;
                    }
     if(teclado==6){  delay_ms(90);dormir=0;
                      banderatimer=0;
                      bandera=reloj(veloc);
                      veloc1=veloc1+1;
                      tiempo=1;
                    }
     // return;
     }
    reinicio=0;
     //if (!RB1)
     //   { 
      //   salir2=1;
      //  }
 }
 return;
} 
//******************** Interrupcin de barrido *******************************//
#int_EXT1
void EXT1(void)
{dormir=0;                     //lo realice para el sleep
  if (RB1)          
  {
                                    //
  do{ delay_ms(80);                 // rutina
      }while(input(pin_B1)==0);     // antirrebote
  
  // RB4=1;                    // activa salida para que salga antes del modo de barrido
   do{ salir=1;                
       cont_displ=cont_displ+1;         
       cont_modo=cont_modo+1;
       display(cont_displ);
       barrido(cont_modo);
       delay_ms(100); //------------------------> antirrebote 
       if(cont_displ>=9) cont_displ=0;          //control del modo de barrido
       if(cont_modo>=9) cont_modo=0;            //**************************//
       }while(input(pin_b1)==0);
     return;
    }
}

//******************** Interrupcin de velocidad *****************************//
#int_EXT2
void EXT2(void)
{dormir=0;                     //lo realice para el sleep
  if (RB2)          
 {
                                   //
  do{delay_ms(80);                 // rutina
     }while(input(pin_B2)==0);     // antirrebote
  
  //RB3=1;             // activa salida
   do{salir=1;                  // para que salga antes del modo   
      cont_displ2=cont_displ2+1;
      cont_modo2=cont_modo2+1;
      display2(cont_displ2);
      veloc = velocidad(cont_modo2);
      delay_ms(100);
      if(cont_displ2>=7) cont_displ2=0;     // control de la velocidad
      if(cont_modo2>=7) cont_modo2=0;       //
      }while(input(pin_b2)==0);
    return;
   }
 }
//****************************************************************************//

#int_timer1
void timer1_isr(void)
{  banderatimer++;
   bandera=reloj(veloc);
   if(banderatimer==bandera)
   {  //output_high(pin_B4);
      reconocer=1;       
      disable_interrupts(INT_TIMER1);
      disable_interrupts(GLOBAL);
      banderatimer=0;
   }
  return;
 }
/******************************************************************************/
/************************** PROGRAMA PRINCIPAL  *******************************/
/******************************************************************************/

 int i=1,j=1,k=1,l=1;
 
 void main()
 {
    dormir=0;                     //lo realice para el sleep    cont_displ=1; cont_displ2=1;
    cont_modo=1; cont_modo2=1;
    veloc=1;veloc1=0;
    output_low(pin_A6);           // inicializa en bajo los leds frontales de alarma
    output_low(pin_C0);           // inicializa en bajo el buzzer de alarma
   
    setup_oscillator(OSC_4MHZ);   // seteo el oscilador a 4Mhz
    inic_memoria();               // funcion que busca en memoria la configuracion inicial
     
     while(true)      // tendria que usarse un case.. y switch
     {
      // inic_memoria();               // funcion que busca en memoria la configuracion inicial
      set_tris_b(0b00001111);      // ********* seteo RB4/5/6/7 como salidas ***********
      set_tris_a(0b00000000);      // ******** todo el puerto A es salida **************
     ext_int_edge(H_to_L);
     enable_interrupts (INT_EXT);
     enable_interrupts (INT_EXT1);
     enable_interrupts (INT_EXT2);
     enable_interrupts (GLOBAL);
     
    // set_tris_b(0b00001111);      // ********* seteo RB4/5/6/7 como salidas ***********
    // set_tris_a(0b00000000);      // ******** todo el puerto A es salida **************
     
     output_low(pin_A0);          //**** Al inicio se colocan en Bajo las filas *********
     output_low(pin_A1);
     output_low(pin_A2);         // *****************************************************
     display(cont_displ);
     barrido(cont_modo);
     display2(cont_displ2);
     
     //******************* Modo 1: Lectura  **********************************//
     
     while(teclado==1)   
                   {                   
                    salir=salir+1;
                    dormir=dormir+1;                     //lo realice para el sleep
                    if((salir==1)&&(stop==0)) modo_lectura(1);
                    if((salir==2)&&(stop==0)) modo_lectura(2);
                    if((salir==3)&&(stop==0)) modo_lectura(3);
                    if((salir==4)&&(stop==0)) modo_lectura(4);
                    if((salir==5)&&(stop==0)) modo_lectura(5);
                    if((salir==6)&&(stop==0)) modo_lectura(6);
                    if((salir==7)&&(stop==0)) modo_lectura(7);
                    if((salir==8)&&(stop==0)) modo_lectura(8);
                    if((salir==9)&&(stop==0)) modo_lectura(9);
                    if((salir==10)&&(stop==0)) modo_lectura(10);
                    if((salir==11)&&(stop==0)) modo_lectura(11);
                    if((salir==12)&&(stop==0)) modo_lectura(12);
                    if((salir==13)&&(stop==0)) salir=0;
                    if(reconocer==1) {alarma(tarjeta1);}
                    if(stop==1) {apago_todo(); reinicio=1;   
                                 sleep(); reconocer=0;      
                                 stop=0;
                                }
                   //*********** ajuste del tiempo de sleep() de acuerdo al modo utilizado*****************/
                   
                  if((dormir==1200)&&((veloc==1)||(veloc==2))){sleep();              //** el procesador entra en modo dormir
                                                               delay_ms(500);}       //** cada medio segundo
                   
                  if((dormir==450)&&((veloc==3)||(veloc==4)||(veloc==5))){sleep();              //** el procesador entra en modo dormir
                                                                         delay_ms(500);}       //** cada medio segundo
                    
                  if((dormir==220)&&((veloc==6)||(veloc==7))){sleep();              //** el procesador entra en modo dormir
                                                             delay_ms(500);}       //** cada medio segundo
                   
                               
                   // salir=0;
                    }
     dormir=0;                     //lo realice para el sleep               
     
     
     //******************* Modo 2: Circular **********************************//
     
     while(teclado==2) 
                    {salir=salir+1;
                     dormir=dormir+1;                     //lo realice para el sleep
                     if((salir==1)&&(stop==0)) modo_circular(1);
                     if((salir==2)&&(stop==0)) modo_circular(2);
                     if((salir==3)&&(stop==0)) modo_circular(3);
                     if((salir==4)&&(stop==0)) modo_circular(4);
                     if((salir==5)&&(stop==0)) modo_circular(5);
                     if((salir==6)&&(stop==0)) modo_circular(6);
                     if((salir==7)&&(stop==0)) modo_circular(7);
                     if((salir==8)&&(stop==0)) modo_circular(8);
                     if((salir==9)&&(stop==0)) modo_circular(9);
                     if((salir==10)&&(stop==0)) modo_circular(10);
                     if((salir==11)&&(stop==0)) salir=0;
                     if(reconocer==1) {alarma(tarjeta1);}
                     if(stop==1) {apago_todo(); reinicio=1;
                                  sleep(); reconocer=0;
                                  stop=0;
                                  }
                         
                   
                    //*********** ajuste del tiempo de sleep() de acuerdo al modo utilizado*****************/
                   
                     if((dormir==1200)&&((veloc==1)||(veloc==2))){sleep();              //** el procesador entra en modo dormir
                                                                  delay_ms(500);}       //** cada medio segundo
                   
                     if((dormir==450)&&((veloc==3)||(veloc==4)||(veloc==5))){sleep();              //** el procesador entra en modo dormir
                                                                             delay_ms(500);}       //** cada medio segundo
                    
                     if((dormir==220)&&((veloc==6)||(veloc==7))){sleep();              //** el procesador entra en modo dormir
                                                                 delay_ms(500);}       //** cada medio segundo
                    
                   
                   
                   
                   
                   
                   
                   }
     dormir=0;                     //lo realice para el sleep               
     
     //***************** Modo 3: 4 esquinas Circular ************************//
     
     while(teclado==3)  
                    {salir=salir+1;
                    dormir=dormir+1;                     //lo realice para el sleep
                    if((salir==1)&&(stop==0)) modo_circular_esq(1);
                    if((salir==2)&&(stop==0)) modo_circular_esq(2);
                    if((salir==3)&&(stop==0)) modo_circular_esq(3);
                    if((salir==4)&&(stop==0)) modo_circular_esq(4);
                    if((salir==5)&&(stop==0)) salir=0;
                    
                    if(reconocer==1) {alarma(tarjeta1);}
                    if(stop==1) {apago_todo(); reinicio=1;
                                 sleep(); reconocer=0;
                                 stop=0;
                                }
                   
                  
                  //*********** ajuste del tiempo de sleep() de acuerdo al modo utilizado*****************/
                   
                  if((dormir==1200)&&((veloc==1)||(veloc==2))){sleep();              //** el procesador entra en modo dormir
                                                               delay_ms(500);}       //** cada medio segundo
                   
                  if((dormir==450)&&((veloc==3)||(veloc==4)||(veloc==5))){sleep();              //** el procesador entra en modo dormir
                                                                         delay_ms(500);}       //** cada medio segundo
                    
                  if((dormir==220)&&((veloc==6)||(veloc==7))){sleep();              //** el procesador entra en modo dormir
                                                             delay_ms(500);}       //** cada medio segundo
                   
                                    
                    
                    
                    
                    }
     dormir=0;                     //lo realice para el sleep               
    
    //****************** Modo 4: 4 esquinas Lectura *************************//
    
    while(teclado==4)  
                   {salir=salir+1;
                    dormir=dormir+1;                     //lo realice para el sleep
                    if((salir==1)&&(stop==0)) modo_lectura_esq(1);
                    if((salir==2)&&(stop==0)) modo_lectura_esq(2);
                    if((salir==3)&&(stop==0)) modo_lectura_esq(3);
                    if((salir==4)&&(stop==0)) modo_lectura_esq(4);
                    if((salir==5)&&(stop==0)) salir=0;
                    
                    if(reconocer==1) {alarma(tarjeta1);}
                    if(stop==1) {apago_todo(); reinicio=1;
                                 sleep(); reconocer=0;
                                 stop=0;
                                }
                   
                  //*********** ajuste del tiempo de sleep() de acuerdo al modo utilizado*****************/
                   
                  if((dormir==1200)&&((veloc==1)||(veloc==2))){sleep();              //** el procesador entra en modo dormir
                                                               delay_ms(500);}       //** cada medio segundo
                   
                  if((dormir==450)&&((veloc==3)||(veloc==4)||(veloc==5))){sleep();              //** el procesador entra en modo dormir
                                                                         delay_ms(500);}       //** cada medio segundo
                    
                  if((dormir==220)&&((veloc==6)||(veloc==7))){sleep();              //** el procesador entra en modo dormir
                                                             delay_ms(500);}       //** cada medio segundo
                   
                               
                                 
                  }
            
     dormir=0;                     //lo realice para el sleep
     
     //**************** Modo 5: Lectura, por pulsado ************************//
     
     while(teclado==5)  
                  {setup_timer_1(T1_INTERNAL|T1_DIV_BY_8|RTCC_8_BIT );
                   enable_interrupts(INT_TIMER1);
                   enable_interrupts(GLOBAL);
                                      
                   if(veloc1==1) modo_lectura2(1);
                   if(veloc1==2) modo_lectura2(2);
                   if(veloc1==3) modo_lectura2(3);
                   if(veloc1==4) modo_lectura2(4);
                   if(veloc1==5) modo_lectura2(5);
                   if(veloc1==6) modo_lectura2(6);
                   if(veloc1==7) modo_lectura2(7);
                   if(veloc1==8) modo_lectura2(8);
                   if(veloc1==9) modo_lectura2(9);
                   if(veloc1==10) modo_lectura2(10);
                   if(veloc1==11) modo_lectura2(11);
                   if(veloc1==12) modo_lectura2(12);
                   if(veloc1==13) veloc1=1;
                   if(tiempo==1)  { set_timer1(0xFFFF);}  //seteo el timer1
                                  
                   if(reconocer==1) {  alarma_2(tarjeta);
                                        reconocer=0;
                                        dormir=dormir+1;
                                    }
                   tiempo=0;
                   if(dormir==3){sleep();                //** make processor sleep
                                 dormir=0;               // esto es para reiniciar el contador
                                 delay_ms(500);}         //** every second
                   }
     veloc1=0;                        // posible correccion         
     dormir=0;                     //lo realice para el sleep
     
     //*************** Modo 6: Circular con pulsador ************************//
     
     while(teclado==6) 
                  {setup_timer_1(T1_INTERNAL|T1_DIV_BY_8);
                   enable_interrupts(INT_TIMER1);
                   enable_interrupts(GLOBAL);
                                   
                   if(veloc1==1) modo_circular2(1);
                   if(veloc1==2) modo_circular2(2);
                   if(veloc1==3) modo_circular2(3);
                   if(veloc1==4) modo_circular2(4);
                   if(veloc1==5) modo_circular2(5);
                   if(veloc1==6) modo_circular2(6);
                   if(veloc1==7) modo_circular2(7);
                   if(veloc1==8) modo_circular2(8);
                   if(veloc1==9) modo_circular2(9);
                   if(veloc1==10) modo_circular2(10);
                   if(veloc1==11) veloc1=1;
                   if(tiempo==1)  { set_timer1(0xFFFF);}  //seteo el timer1
                                  
                  if(reconocer==1) { alarma_2(tarjeta);
                                     reconocer=0;
                                     dormir=dormir+1;
                                   }
                   tiempo=0;
                   if(dormir==3){sleep();                //** make processor sleep
                                dormir=0;               // esto es para reiniciar el contador
                                delay_ms(500);}         //** every second
                   }
     veloc1=1; 
     dormir=0;                     //lo realice para el sleep
     
     //************** Modo 7: Lectura, continuo ******************************//
     
     while(teclado==7)  
             {disable_interrupts (INT_EXT);
              
             while(!input(pin_b0))    
                  { saltar=saltar+1;
                    reconocer=1;                               //  habilito alarma              
                    if(saltar==1){modo_lectura2(1); retardo(veloc); }
                    if(saltar==2){modo_lectura2(2); retardo(veloc); }
                    if(saltar==3){modo_lectura2(3); retardo(veloc); }
                    if(saltar==4){modo_lectura2(4); retardo(veloc); }
                    if(saltar==5){modo_lectura2(5); retardo(veloc); }
                    if(saltar==6){modo_lectura2(6); retardo(veloc); }
                    if(saltar==7){modo_lectura2(7); retardo(veloc); }
                    if(saltar==8){modo_lectura2(8); retardo(veloc); }
                    if(saltar==9){modo_lectura2(9); retardo(veloc); }
                    if(saltar==10){modo_lectura2(10); retardo(veloc); }
                    if(saltar==11){modo_lectura2(11); retardo(veloc); }
                    if(saltar==12){modo_lectura2(12); retardo(veloc); }
                    if(saltar==13) saltar=0;
                 }
             if(reconocer==1) {  alarma_2(tarjeta);      //
                                 reconocer=0;            //
                              }                          //
             
             }
       saltar=0;
       
      //************* Modo 8: Circular, continuo *****************************//
       
      while(teclado==8)
             {disable_interrupts (INT_EXT);  //se deshabilita B0 para que ese pin funcione como entrada comun
              while(!input(pin_b0))    
                   {saltar1=saltar1+1;
                    reconocer=1;
                    if(saltar1==1){modo_circular2(1);  retardo(veloc);}
                    if(saltar1==2){modo_circular2(2);  retardo(veloc);}
                    if(saltar1==3){modo_circular2(3);  retardo(veloc);} 
                    if(saltar1==4){modo_circular2(4);  retardo(veloc);}
                    if(saltar1==5){modo_circular2(5);  retardo(veloc);}
                    if(saltar1==6){modo_circular2(6);  retardo(veloc);}
                    if(saltar1==7){modo_circular2(7);  retardo(veloc);}
                    if(saltar1==8){modo_circular2(8);  retardo(veloc);}
                    if(saltar1==9){modo_circular2(9);  retardo(veloc);}
                    if(saltar1==10){modo_circular2(10); retardo(veloc);}
                    if(saltar1==11) saltar1=0;
                   }
            if(reconocer==1){  alarma_2(tarjeta);
                               reconocer=0; } 
           }
       saltar1=0;            
       enable_interrupts (INT_EXT);
       enable_interrupts (INT_EXT1);
       enable_interrupts (INT_EXT2);
       enable_interrupts (GLOBAL);  
         
      //************** Modo 9: 2 tarjetas ************************************//
       
      while(teclado==9)
           {      
            enable_interrupts (INT_EXT);        // redundancia de codigo para probar 
            enable_interrupts (INT_EXT1);       // que se habiliten las interrupciones
            enable_interrupts (INT_EXT2);       //
            enable_interrupts (GLOBAL);         //
                            
                    salir=salir+1;
                    dormir=dormir+1;                     //lo realice para el sleep
                    if((salir==1)&&(stop==0)) modo_dos_tarjetas(1);
                    if((salir==2)&&(stop==0)) modo_dos_tarjetas(2);
                    if((salir==3)&&(stop==0)) modo_dos_tarjetas(3);
                    if((salir==4)&&(stop==0)) modo_dos_tarjetas(4);
                    if((salir==5)&&(stop==0)) modo_dos_tarjetas(5);
                    if((salir==6)&&(stop==0)) modo_dos_tarjetas(6);
                    if((salir==7)&&(stop==0)) salir=0;
                   
                   if(reconocer==1) {alarma(tarjeta1);}
                    if(stop==1) {apago_todo(); reinicio=1;
                                 sleep(); reconocer=0;
                                 stop=0;
                                }
                   
            
            
            //*********** ajuste del tiempo de sleep() de acuerdo al modo utilizado*****************/
                   
                  if((dormir==1200)&&((veloc==1)||(veloc==2))){sleep();              //** el procesador entra en modo dormir
                                                               delay_ms(500);}       //** cada medio segundo
                   
                  if((dormir==450)&&((veloc==3)||(veloc==4)||(veloc==5))){sleep();              //** el procesador entra en modo dormir
                                                                         delay_ms(500);}       //** cada medio segundo
                    
                  if((dormir==220)&&((veloc==6)||(veloc==7))){sleep();              //** el procesador entra en modo dormir
                                                             delay_ms(500);}       //** cada medio segundo
                      
             }
                            
     }
 }
 
 //*************************** FUNCIONES *************************************//
//***************** funcin de inicio con memoria ***************************//

void inic_memoria(void)
{
    teclado=read_EEPROM (NUM_TECLADO);   //leer memoria
    veloc=read_EEPROM (NUM_VELOC);      //leer memoria
    if(veloc==0xFF) veloc=1;              // esto borra el registro de la memoria al iniciar luego de grabar el pic
    if((teclado>9)||(teclado<1)) teclado=1;
       
    if(teclado>1)  teclado=teclado-1;      //***** modificacion para ver que no se incremente en 1 el estado de la memoria (modos)
    if(teclado==1){cont_displ=1;           //-------------------------------
                   cont_modo=1;            //------- modo de teclado--------
                  }
    if(teclado==2){cont_displ=2;cont_modo=2; }
    if(teclado==3){cont_displ=3;cont_modo=3; }
    if(teclado==4){cont_displ=4;cont_modo=4; }
    if(teclado==5){cont_displ=5;cont_modo=5; }
    if(teclado==6){cont_displ=6;cont_modo=6; }
    if(teclado==7){cont_displ=7;cont_modo=7; }
    if(teclado==8){cont_displ=8;cont_modo=8; }
    if(teclado==9){cont_displ=9;cont_modo=9; }  
    
    if(veloc==1){cont_displ2=1;      //----------------------------------
                 cont_modo2=1;       //--------- velocidad --------------
                }
    if(veloc==2){cont_displ2=2;cont_modo2=2; }
    if(veloc==3){cont_displ2=3;cont_modo2=3; }
    if(veloc==4){cont_displ2=4;cont_modo2=4; }
    if(veloc==5){cont_displ2=5;cont_modo2=5; }
    if(veloc==6){cont_displ2=6;cont_modo2=6; }
    if(veloc==7){cont_displ2=7;cont_modo2=7; }
}
 
//******************* Funcion Modo de Lectura automatico MODO 1 **************//
void modo_lectura(int i1)
{   
 //---------------------------------------ASM-------------------------------
    #asm
  
    BSF  EECON1,  WREN;    // habilita escritura
    #endasm
    delay_ms(25);
    write_eeprom(NUM_TECLADO,teclado);  // escribir memoria
    write_eeprom(NUM_VELOC,veloc);      // escribir memoria 
    #asm
    BCF  EECON1, WREN;    // deshabilita escritura
    #endasm
 //------------------------------------------------------------------------   
        
    if(i==1)
       {  //output_low(pin_A4);               
            output_high(pin_A0);
            output_low(pin_A1);
            output_low(pin_A2);
          //output_high(pin_B4);
  //----------------------------------------------------                                  
   if(i1==1){tarjeta=1;
                                       
             output_low(pin_A3);
             output_low(pin_A4);
             output_low(pin_A5);
             output_high(pin_A7);     // enciende el LED D1      
             retardo(veloc);
             output_low(pin_A7);
                                        
            }
         //-----------------------------------------------------
   if(i1==2){tarjeta=2;
             output_high(pin_A5);     // enciende el LED D2
             retardo(veloc);
             output_low(pin_A5);
            }
         //-----------------------------------------------------
    if(i1==3){tarjeta=3;
              output_high(pin_A4);     // enciende el LED D3
              retardo(veloc);
              output_low(pin_A4);
              }
         //----------------------------------------------------
   if(i1==4){tarjeta=4; 
             output_low(pin_A2);      // correccion de un posible encendido de led 12
             output_high(pin_A3);     // enciende el LED D4
             retardo(veloc);
             output_low(pin_A3);
            }
       i=i+1;
     }
       
     if(i==2)
       {  output_low(pin_A0);            
          output_high(pin_A1);
          output_low(pin_A2);
         //---------------------------------------------------       
    if(i1==5){tarjeta=5;
              output_high(pin_A7);    
              retardo(veloc);
              output_low(pin_A7);
             }
         //--------------------------------------------------
    if(i1==6){tarjeta=6;
              output_high(pin_A5);     // enciende el LED D6
              retardo(veloc);
              output_low(pin_A5);
             }
       //---------------------------------------------------
    if(i1==7){tarjeta=7;
             output_high(pin_A4);     // enciende el LED D7
             retardo(veloc);
             output_low(pin_A4);
             }
         //---------------------------------------------------
    if(i1==8){tarjeta=8;
              output_high(pin_A3);     // enciende el LED D8
              retardo(veloc);
              output_low(pin_A3);
              }
       i=i+1;
       }
        
   if(i==3)
       {
          output_low(pin_A0);
          output_low(pin_A1);
          output_high(pin_A2);
        //----------------------------------------------------
   if(i1==9){tarjeta=9;                // enciende el LED 9
             output_high(pin_A7);
             retardo(veloc);
             output_low(pin_A7);
            }
        //----------------------------------------------------
   if(i1==10){tarjeta=10;
              output_high(pin_A5);     // enciende el LED D10
              retardo(veloc);
              output_low(pin_A5);
             }
        //---------------------------------------------------
  if(i1==11){tarjeta=11;
             output_high(pin_A4);     // enciende el LED D11
             retardo(veloc);
             output_low(pin_A4);
           }
        //---------------------------------------------------
    if(i1==12){tarjeta=12;
              output_high(pin_A3);    // enciende el LED D12
              retardo(veloc);
              output_low(pin_A3);
              }
    i1=1;
    i=1;
   }        
return;
}
//******************* Funcin Modo Circular **********************************//

void modo_circular(int i2)
{   
//---------------------------------------ASM-------------------------------
    #asm
    BSF EECON1, WREN    // habilita escritura
    #endasm
    delay_ms(25);
    write_eeprom(NUM_TECLADO,teclado);  // escribir memoria
    write_eeprom(NUM_VELOC,veloc);      // escribir memoria 
    #asm
    BCF EECON1, WREN    // deshabilita escritura
    #endasm
 //------------------------------------------------------------------------ 

if(j==1)
       {  output_high(pin_A0);
          output_low(pin_A1);
          output_low(pin_A2);
          
         //---------------------------------------------------------                                   
   if(i2==1){tarjeta=1;
            
             output_high(pin_A7);     // enciende el LED D1
             retardo(veloc);
             output_low(pin_A7);
            }
        //---------------------------------------------------------
   if(i2==2){tarjeta=2;
             output_high(pin_A5);    // enciende el LED D2
             retardo(veloc);
             output_low(pin_A5);
            }
         //---------------------------------------------------------
   if(i2==3){tarjeta=3;
             output_high(pin_A4);    // enciende el LED D3
             retardo(veloc);
             output_low(pin_A4);
            }       
         //---------------------------------------------------------
   if(i2==4){tarjeta=4;
             output_high(pin_A3);    // enciende el LED D4
             retardo(veloc);
             output_low(pin_A3);
            }
       j=j+1;
       }
       
 if(j==2)
        { output_low(pin_A0);            
          output_high(pin_A1);
          output_low(pin_A2);
          
          //------------------------------------------------------        
     if(i2==5){tarjeta=8;
               output_low(pin_A4);      // enciende el LED D8
               output_low(pin_A5);
               output_low(pin_A7);   
               output_high(pin_A3);
               retardo(veloc);
               output_low(pin_A3);
              }
        j=j+1;
       }
        
     if(j==3)
       {  output_low(pin_A0);
          output_low(pin_A1);
          output_high(pin_A2);
          
         //---------------------------------------------------
   if(i2==6){tarjeta=12;
             output_low(pin_A4);     // enciende el LED D12
             output_low(pin_A5);
             output_low(pin_A7);
             
             output_high(pin_A3);    
             retardo(veloc);
             output_low(pin_A3);
            }
         //----------------------------------------------------
   if(i2==7){tarjeta=11;
             output_high(pin_A4);    // enciende el LED D11
             retardo(veloc);
             output_low(pin_A4);
            }
        //-----------------------------------------------------
  if(i2==8){tarjeta=10;
            output_high(pin_A5);     // enciende el LED D10
            retardo(veloc);
            output_low(pin_A5);
           }
       //------------------------------------------------------
  if(i2==9){tarjeta=9;
            output_high(pin_A7);    // enciende el LED D9
            retardo(veloc);
            output_low(pin_A7);
           }
        j=j-1;
         }
        
  if(j==2)
       {  output_low(pin_A0);            
          output_high(pin_A1);
          output_low(pin_A2);
          
         //------------------------------------------------------------     
    if(i2==10){tarjeta=5;
             output_high(pin_A7);       // enciende el LED D5
             retardo(veloc);
             output_low(pin_A7);
             }
      j=1;
      } 
   return;
}

//******************** Funcin Circular Esquinas *****************************//
void modo_circular_esq(int i3)
{   
//---------------------------------------ASM-------------------------------
    #asm
    BSF EECON1, WREN    // habilita escritura
    #endasm
    delay_ms(25);
    write_eeprom(NUM_TECLADO,teclado);  // escribir memoria
    write_eeprom(NUM_VELOC,veloc);      // escribir memoria 
    #asm
    BCF EECON1, WREN    // deshabilita escritura
    #endasm
 //------------------------------------------------------------------------ 
 
 if(k==1)                        //----------------- primer fila
      {  output_low(pin_A4);
         output_high(pin_A0);
         output_low(pin_A1);
         output_low(pin_A2);
        //-------------------------------------------------------
   if(i3==1){tarjeta=1;
             output_low(pin_A3);
             output_low(pin_A4);
             output_low(pin_A5);
             
             output_high(pin_A7);       // enciende el LED D1
             retardo(veloc);
             output_low(pin_A7);
             }
        //-------------------------------------------------------
    if(i3==2){     
              tarjeta=4;
              output_low(pin_A4);
              output_low(pin_A5);
              output_low(pin_A7);
              
              output_high(pin_A3);      // enciende el LED D4
              retardo(veloc);
              output_low(pin_A3);
              }
        k=k+1;
        }
       
   if(k==2)                     // ------------------ cuarta fila
      {   output_low(pin_A0);
          output_low(pin_A1);
          output_high(pin_A2);
         //-------------------------------------------------------
   if(i3==3){tarjeta=12;
             output_low(pin_A4);
             output_low(pin_A5);
             output_low(pin_A3); 
             
             
             output_high(pin_A3);     // enciende el LED D12
             retardo(veloc);
             output_low(pin_A3);
             }
        //-------------------------------------------------------
  if(i3==4){tarjeta=9;
            output_low(pin_A4);
            output_high(pin_A7);      // enciende el LED D9
            retardo(veloc);
            output_low(pin_A7);
            }
        k=1;
         }      
 return;
}

//******************* Funcin Modo Lectura Esquinas **************************//

void modo_lectura_esq(int i4)
{  
 //---------------------------------------ASM-------------------------------
    #asm
    BSF EECON1, WREN    // habilita escritura
    #endasm
    delay_ms(25);
    write_eeprom(NUM_TECLADO,teclado);  // escribir memoria
    write_eeprom(NUM_VELOC,veloc);      // escribir memoria 
    #asm
    BCF EECON1, WREN    // deshabilita escritura
    #endasm
 //------------------------------------------------------------------------ 
 
 if(l==1)
       {  output_high(pin_A0);        //------------ primer fila
          output_low(pin_A1);
          output_low(pin_A2);
         //------------------------------------------------------                          
     if(i4==1){tarjeta=1;
                             
               output_high(pin_A7);     // enciende el LED D1
               retardo(veloc);
               output_low(pin_A7);
              }
         //-----------------------------------------------------
     if(i4==2){tarjeta=4;
              
               output_high(pin_A3);    // enciende el LED D4
               retardo(veloc);
               output_low(pin_A3);
              }
        l=l+1;
        }
       
       if(l==2)
       {  
          output_low(pin_A0);         //------------ cuarta fila
          output_low(pin_A1);
          output_high(pin_A2);
        //-----------------------------------------------------                                 
    if(i4==3){tarjeta=9;
              output_high(pin_A7);    // enciende el LED D9
              retardo(veloc);
              output_low(pin_A7);
             }
        //-----------------------------------------------------
    if(i4==4){tarjeta=12;
                                      
              output_high(pin_A3);    // enciende el LED D12
              retardo(veloc);
              output_low(pin_A3);
             }
        l=1;
         }
 return;      
}            
 //******************** Funcion Display (BARRIDO)*****************************//
 
 void display (int x)
 {set_tris_c(0b00000000);           //salidas port c
   if(x==1){  
              output_high(pin_B4);   //  LSB
              output_low(pin_B5);
              output_low(pin_B6);
              output_low(pin_B7);    //  MSB
            }
    if(x==2){ output_low(pin_B4);    //  LSB
              output_high(pin_B5);
              output_low(pin_B6);
              output_low(pin_B7);    //  MSB
            }
    if(x==3){ output_high(pin_B4);   //  LSB
              output_high(pin_B5);
              output_low(pin_B6);
              output_low(pin_B7);    //  MSB
            }
    if(x==4){ output_low(pin_B4);    //  LSB
              output_low(pin_B5);
              output_high(pin_B6);
              output_low(pin_B7);    //  MSB
            }
    if(x==5){ output_high(pin_B4);   //  LSB
              output_low(pin_B5);
              output_high(pin_B6);
              output_low(pin_B7);    //  MSB
            }
    if(x==6){output_low(pin_B4);     //  LSB
             output_high(pin_B5);
             output_high(pin_B6);
             output_low(pin_B7);     //  MSB
            }
    if(x==7){ output_high(pin_B4);   //  LSB
              output_high(pin_B5);
              output_high(pin_B6);
              output_low(pin_B7);    //  MSB
            }
    if(x==8){ output_low(pin_B4);    //  LSB
              output_low(pin_B5);
              output_low(pin_B6);
              output_high(pin_B7);    // MSB
           }
   if(x==9){  output_high(pin_B4);   //  LSB
              output_low(pin_B5);
              output_low(pin_B6);
              output_high(pin_B7);    // MSB
           }
 return;
 }
 //****************** Funcion Display2 (VELOCIDAD) ***************************//
 
 void display2(int x2)
 {set_tris_c(0b00000000);            //salidas port c
   if(x2==1){ output_low(pin_C2);    // LSB  " inprime 0. (indican 1/2 segundo) "
              output_low(pin_C3);
              output_low(pin_C4);
              output_low(pin_C5);    // MSB
              //output_high(pin_C1); // enciende el led de punto decimal 
            }
   if(x2==2){ output_high(pin_C2);   //  LSB   **** imprime 1
              output_low(pin_C3);
              output_low(pin_C4);
              output_low(pin_C5);    //  MSB
              output_low(pin_C1);
           }
   if(x2==3){ output_low(pin_C2);    // LSB   **** imprime 2
              output_high(pin_C3);
              output_low(pin_C4);
              output_low(pin_C5);    //  MSB
              output_low(pin_C1);
            }
   if(x2==4){ output_high(pin_C2);   //  LSB  ***** imprime 3
              output_high(pin_C3);
              output_low(pin_C4);
              output_low(pin_C5);    //  MSB
              output_low(pin_C1);
            }
   if(x2==5){ output_low(pin_C2);    //  LSB   *** imprime 4
              output_low(pin_C3);
              output_high(pin_C4);
              output_low(pin_C5);    //  MSB
              output_low(pin_C1);
            }
    if(x2==6){output_high(pin_C2);   //  LSB   *** imprime 5
             output_low(pin_C3);
             output_high(pin_C4);
             output_low(pin_C5);     //  MSB
             output_low(pin_C1);
            }
    if(x2==7){ output_low(pin_C2);   //  LSB   *** imprime 6
              output_high(pin_C3);
              output_high(pin_C4);
              output_low(pin_C5);    //  MSB
              output_low(pin_C1);
             }
   
 return;
 }
 
 //************************* Funcin Barrido *********************************//
 void barrido(int y)
 {
   if(y==1) teclado=1;
   if(y==2) teclado=2;
   if(y==3) teclado=3;
   if(y==4) teclado=4;
   if(y==5) teclado=5;
   if(y==6) teclado=6;
   if(y==7) teclado=7;
   if(y==8) teclado=8;
   if(y==9) teclado=9;
 delay_ms(100);
 return;
 }
  //*********************** Funcin Velocidad ********************************//
 int velocidad(int y2)
 {
   if(y2==1) veloc=1;
   if(y2==2) veloc=2;
   if(y2==3) veloc=3;
   if(y2==4) veloc=4;
   if(y2==5) veloc=5;
   if(y2==6) veloc=6;
   if(y2==7) veloc=7;
 delay_ms(100);
 return veloc;
 }
 
 //*********************** Funcin de Retardo ********************************//
 
void retardo(int z)
{
 if(z==1) delay_ms(500);
 if(z==2) delay_ms(1000);
 if(z==3) delay_ms(2000);
 if(z==4) delay_ms(3000);
 if(z==5) delay_ms(4000);
 if(z==6) delay_ms(5000);
 if(z==7) delay_ms(6000);
 return;
}
 //********************* Funcin para Cambio de Velocidad ********************//
 int reloj(int w)
 {
 int bandera;
 if(w==1) { bandera=5;     }
 if(w==2) { bandera=10;    }        
 if(w==3) { bandera=20;    }
 if(w==4) { bandera=40;    }         
 if(w==5) { bandera=60;    }         
 if(w==6) { bandera=100;   }         
 if(w==7) { bandera=120;   }         
 return (bandera);
}
//********************* Funcin modo de lectura2 (barrido MANUAL)*************//

void modo_lectura2(int i3)
{   
//---------------------------------------ASM-------------------------------
    #asm
    BSF EECON1, WREN    // habilita escritura
    #endasm
    delay_ms(25);
    write_eeprom(NUM_TECLADO,teclado);  // escribir memoria
    write_eeprom(NUM_VELOC,veloc);      // escribir memoria 
    #asm
    BCF EECON1, WREN    // deshabilita escritura
    #endasm
 //------------------------------------------------------------------------ 

    if((i3==1)||(i3==2)||(i3==3)||(i3==4))
       {  
             
             output_high(pin_A0);
             output_low(pin_A1);
             output_low(pin_A2);
             
//-----------------------------------------------------------------                                  
  if(i3==1){  
             tarjeta=1;
             output_low(pin_A3);      // enciende el LED D1
             output_low(pin_A4);
             output_low(pin_A5);
             output_high(pin_A7);     
             
           }
//------------------------------------------------------------------
  if(i3==2){   
             tarjeta=2;
             output_low(pin_A4);
             output_low(pin_A7);
             output_high(pin_A5);     // enciende el LED D2
             
           }
//------------------------------------------------------------------
  if(i3==3){ tarjeta=3;
             output_high(pin_A0);
             output_low(pin_A1);
             output_low(pin_A2);
             output_low(pin_A5);
             output_high(pin_A4);     // enciende el LED D3
            }
//-----------------------------------------------------------------
  if(i3==4){ tarjeta=4;
             output_low(pin_A4);
             output_high(pin_A3);     // enciende el LED D4
             
           }
    }
       
  if((i3==5)||(i3==6)||(i3==7)||(i3==8))   // ------ segunda fila -------
     {         output_low(pin_A0);
               output_high(pin_A1);
               output_low(pin_A2);
//------------------------------------------------------------------       
  if(i3==5){  tarjeta=5;
              output_low(pin_A3);      // enciende el LED D5
              output_low(pin_A4);
              output_low(pin_A5);
              output_high(pin_A7);     // Encender LED en salida B0.
            }
//------------------------------------------------------------------
  if(i3==6){  tarjeta=6;
              output_low(pin_A7);
              output_high(pin_A5);     // enciende el LED D6
              
            }
//------------------------------------------------------------------
  if(i3==7){  tarjeta=7;
              output_low(pin_A5);
              output_high(pin_A4);     // enciende el LED D7
       
           }
//------------------------------------------------------------------
  if(i3==8){  tarjeta=8;
              output_low(pin_A4);
              output_high(pin_A3);     // enciende el LED D8
           }
    }
        
 if((i3==9)||(i3==10)||(i3==11)||(i3==12))
      {
       output_low(pin_A0);
       output_low(pin_A1);
       output_high(pin_A2);
//-------------------------------------------------------------------
  if(i3==9){ tarjeta=9;
             output_low(pin_A3);      
             output_high(pin_A7);      // enciende el LED D9
            }
//-------------------------------------------------------------------
  if(i3==10){ tarjeta=10;
              output_low(pin_A7);
              output_high(pin_A5);     // enciende el LED D10
            }
//-------------------------------------------------------------------
  if(i3==11){ tarjeta=11;
              output_low(pin_A5);
              output_high(pin_A4);     // enciende el LED D11
            }
//-------------------------------------------------------------------
  if(i3==12){ tarjeta=12;
              output_low(pin_A4);
              output_high(pin_A3);    // enciende el LED D12
            }
  //i3=1;
  //i=1;
      }        
return;
}
//******************Funcin Modo Circular2 (Barrido MANUAL) ******************//

void modo_circular2(int i5)
{  
 //---------------------------------------ASM----------------------------------
    #asm
    BSF EECON1, WREN    // habilita escritura
    #endasm
    delay_ms(25);
    write_eeprom(NUM_TECLADO,teclado);  // escribir memoria
    write_eeprom(NUM_VELOC,veloc);      // escribir memoria 
    #asm
    BCF EECON1, WREN    // deshabilita escritura
    #endasm
 //---------------------------------------------------------------------------- 

if((i5==1)||(i5==2)||(i5==3)||(i5==4))
       {  output_high(pin_A0);
          output_low(pin_A1);
          output_low(pin_A2);
          
 //----------------------------------------------------------------------------                                   
   if(i5==1){tarjeta=1;
             output_low(pin_A3);        // enciende el LED D1
             output_low(pin_A4);      
             output_low(pin_A5);
             output_high(pin_A7);    
          
           }
 //----------------------------------------------------------------------------
   if(i5==2){tarjeta=2;
             output_low(pin_A7);
             output_high(pin_A5);       // enciende el LED D2
            }
         //--------------------------------------------------------------------
   if(i5==3){tarjeta=3;
             output_low(pin_A5);
             output_high(pin_A4);       // enciende el LED D3
            }       
         //--------------------------------------------------------------------
   if(i5==4){tarjeta=4;
             output_low(pin_A4);
             output_high(pin_A3);       // enciende el LED D4
            }
       }       
   if(i5==5)
           {output_low(pin_A0);            
            output_high(pin_A1);
            output_low(pin_A2);
          
 //----------------------------------------------------------------------------        
            tarjeta=8;
            output_high(pin_A3);         // enciende el LED D8
            //retardo(veloc);   
            //output_low(pin_A3);
            
        }
        
   if((i5==6)||(i5==7)||(i5==8)||(i5==9))
       {  output_low(pin_A0);
          output_low(pin_A1);
          output_high(pin_A2);
          
         //--------------------------------------------------------------------
   if(i5==6){tarjeta=12;
             
             output_high(pin_A3);       // enciende el LED D12
                         
           }
         //--------------------------------------------------------------------
   if(i5==7){tarjeta=11;
             output_low(pin_A3);
             output_high(pin_A4);
                                        // enciende el LED D11
            }
        //---------------------------------------------------------------------
  if(i5==8){tarjeta=10;
            output_low(pin_A4);
            output_high(pin_A5);        // enciende el LED D10
         
           }
       //----------------------------------------------------------------------
  if(i5==9){tarjeta=9;
            output_low(pin_A5);
            output_high(pin_A7);        // enciende el LED D9
           }
     }
        
  if(i5==10){ 
             output_low(pin_A0);
             output_high(pin_A1);
             output_low(pin_A2);
          
      //-----------------------------------------------------------------------     
             tarjeta=5;
             output_high(pin_A7);        // enciende el LED D5
           }
   return;
}
//******************* Funcin Modo 2 Tarjetas ********************************//

void modo_dos_tarjetas(int i6)
{   
//---------------------------------------ASM-----------------------------------
    #asm
    BSF EECON1, WREN    // habilita escritura
    #endasm
    delay_ms(25);
    write_eeprom(NUM_TECLADO,teclado);  // escribir memoria
    write_eeprom(NUM_VELOC,veloc);      // escribir memoria 
    #asm
    BCF EECON1, WREN    // deshabilita escritura
    #endasm
 //---------------------------------------------------------------------------- 
 
 if(i==1)
       {  
          output_high(pin_A0);
          output_low(pin_A1);
          output_low(pin_A2);
          
        //---------------------------------------------------------------------                                  
   if(i6==1){tarjeta=21;
                                     
             output_low(pin_A3);
             output_low(pin_A4);
             
             output_high(pin_A5);
             output_high(pin_A7);    
             retardo(veloc);
             output_low(pin_A7);
             output_low(pin_A5);
                                    
            }
         //--------------------------------------------------------------------
   if(i6==2){tarjeta=22;
             output_high(pin_A3);
             output_high(pin_A4);    // enciende el LED D2
             retardo(veloc);
             output_low(pin_A4);
             output_low(pin_A3);
            }
         //--------------------------------------------------------------------
     i=i+1;
     }
  if(i==2)
       {  output_low(pin_A0);            
          output_high(pin_A1);
          output_low(pin_A2);
            
      if(i6==3){tarjeta=23;
             output_high(pin_A5);
             output_high(pin_A7);    // enciende el LED 
             retardo(veloc);
             output_low(pin_A7);
             output_low(pin_A5);
              }
         //--------------------------------------------------------------------
   if(i6==4){tarjeta=24; 
             output_high(pin_A3);
             output_high(pin_A4);    // enciende el LED D2
             retardo(veloc);
             output_low(pin_A4);
             output_low(pin_A3);
                               
             }
       i=i+1;
     }
       
     if(i==3)
       {  output_low(pin_A0);            
          output_low(pin_A1);
          output_high(pin_A2);
          
          //-------------------------------------------------------------------       
    if(i6==5){tarjeta=25;
              output_high(pin_A5);
              output_high(pin_A7);    // enciende el LED 
              retardo(veloc);
              output_low(pin_A7);
              output_low(pin_A5);
             }
         //--------------------------------------------------------------------
    if(i6==6){tarjeta=26;
              output_high(pin_A3);
              output_high(pin_A4);    // enciende el LED D2
              retardo(veloc);
              output_low(pin_A4);
              output_low(pin_A3);
             }
       }
i6=1;
i=1;
return;
}     


//******************* Funcin de alarma  (eleccion de tarjeta) ***************//
void alarma(int v)  
{ int t=0;
  
if(v==1){
        while((t<=10)&&(stop==0)){
              output_high(pin_A6);            // enciende las luces frontales de alarma
              if(t<=6) output_high(pin_C0);   // enciende el Buzzer
              output_high(pin_A0);
              output_low(pin_A1);
              output_low(pin_A2);
              output_high(pin_A7);
              output_low(pin_A5);         
              output_low(pin_A4); 
              output_low(pin_A3);
              if(t<=5) delay_ms(100);         //**
              delay_ms(100);                  //**
              if(t<=6) output_low(pin_C0);    //**   apago el buzzer
              if(t<=5) delay_ms(100);         //**
              delay_ms(100);                  //**
              if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
              if(t<=5) delay_ms(100);         //**
              delay_ms(100);                  //**
              if(t<=6) output_low(pin_C0);    // apago el buzzer
              if(t>6) delay_ms(450);          //** son 3 de 150
            
              output_low(pin_A7);    // apaga tarjeta N1
              output_low(pin_A6);    // apago las luces frontales de alarma
              delay_ms(250);
              delay_ms(250);
              delay_ms(250);
              t++;
          }
         while(stop==0){  output_high(pin_A7);}  
         }
 if(v==2){
          while((t<=10)&&(stop==0)) {output_high(pin_A6);            // enciende las Luces frontales de alarma
             if(t<=6) output_high(pin_C0);   // enciende el Buzzer
             output_high(pin_A0); 
             output_low(pin_A1);
             output_low(pin_A2);
             output_low(pin_A7);
             output_high(pin_A5);         
             output_low(pin_A4); 
             output_low(pin_A3);
                                  
             if(t<=5) delay_ms(100);         //**
             delay_ms(100);                  //**
             if(t<=6) output_low(pin_C0);    //**  apaga el Buzzer
             if(t<=5) delay_ms(100);         //**
             delay_ms(100);                  //**
             if(t<=6) output_high(pin_C0);   //**  enciende el Buzzer
             if(t<=5) delay_ms(100);         //**
             delay_ms(100);                  //**
             if(t<=6) output_low(pin_C0);    // apago el buzzer
             if(t>6) delay_ms(450);          //** son 3 de 150
            
             output_low(pin_C0);     // apago el buzzer
             output_low(pin_A5);     // apaga tarjeta N2     
             output_low(pin_A6);     // apago las luces frontales de alarma
             delay_ms(250);
             delay_ms(250);
             delay_ms(250);
             t++;
             }     
            
       while(stop==0){output_high(pin_A5); } 
     }
 if(v==3){
        while((t<=10)&&(stop==0))
           {output_high(pin_A6);           // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);  // enciende el Buzzer
            output_high(pin_A0); 
            output_low(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          
            output_high(pin_A4); 
            output_low(pin_A3);
            
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
           if(t<=5) delay_ms(100);          //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);   // apago el buzzer
            output_low(pin_A4);   // apaga tarjeta N3
            output_low(pin_A6);   // apago las luces frontales de alarma
            //delay_ms(750);
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
           while(stop==0){ output_high(pin_A4);
                         } 
         }
 if(v==4){
         while((t<=10)&&(stop==0))
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_high(pin_A0); 
            output_low(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          
            output_low(pin_A4); 
            output_high(pin_A3);
           
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**  apago el Buzzer
           if(t<=5) delay_ms(100);          //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**  enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A3);
            output_low(pin_A6);             // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
         while(stop==0){output_high(pin_A3);
                       }  
         }
 if(v==5){
          while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0);
            output_high(pin_A1);
            output_low(pin_A2);
            output_high(pin_A7);
            output_low(pin_A5);          
            output_low(pin_A4); 
            output_low(pin_A3);
          
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A7);
            output_low(pin_A6);       // apago las luces frontales de alarma
            //delay_ms(750);
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
         while(stop==0){output_high(pin_A7);
                       } 
         }        
   if(v==6){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0);
            output_high(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_high(pin_A5);          
            output_low(pin_A4); 
            output_low(pin_A3);
           
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A5);
            output_low(pin_A6);    // apago las luces frontales de alarma
            // delay_ms(750);
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
         while(stop==0){output_high(pin_A5); 
                       }
                }

  if(v==7){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_high(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          
            output_high(pin_A4); 
            output_low(pin_A3);
            //delay_ms(400);
            
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
           if(t<=5) delay_ms(100);          //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A4);
            output_low(pin_A6);        // apago las luces frontales de alarma
            //delay_ms(750);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
         while(stop==0){output_high(pin_A4);
                       }
         }
   if(v==8){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_high(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          
            output_low(pin_A4); 
            output_high(pin_A3);
            
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A3);
            output_low(pin_A6);         // apago las luces frontales de alarma
            
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
          while(stop==0){ output_high(pin_A3);
                       }  
         }      
   if(v==9){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_low(pin_A1);
            output_high(pin_A2);
            output_high(pin_A7);
            output_low(pin_A5);          
            output_low(pin_A4); 
            output_low(pin_A3);
            
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A7);
            output_low(pin_A6);         // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
          while(stop==0){ output_high(pin_A2);output_high(pin_A7);
                         }   
         }      
    if(v==10){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_low(pin_A1);
            output_high(pin_A2);
            output_low(pin_A7);
            output_high(pin_A5);          
            output_low(pin_A4); 
            output_low(pin_A3);
            
           if(t<=5) delay_ms(100);          //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A5);
            output_low(pin_A6);        // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
          while(stop==0){ output_high(pin_A2); output_high(pin_A5);  
                        }  
         }     
   if(v==11){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_low(pin_A1);
            output_high(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);         
            output_high(pin_A4); 
            output_low(pin_A3);
             
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_A4);
            output_low(pin_A6);       // apago las luces frontales de alarma
           
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
          while(stop==0){ output_high(pin_A4); output_high(pin_A6);
                        }  
        
        }
   if(v==12){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de larma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_low(pin_A1);
            output_high(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          
            output_low(pin_A4); 
            output_high(pin_A3);
             
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0); 
            output_low(pin_A3);
            output_low(pin_A6);         // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250); 
            t++;
           }
          while(stop==0){ output_high(pin_A3); output_high(pin_A6);
                        }   
         }


 if(v==21){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_high(pin_A0);   
            output_low(pin_A1);
            output_low(pin_A2);
            output_high(pin_A7);
            output_high(pin_A5);          
            output_low(pin_A4);
            output_low(pin_A3);
            //delay_ms(400);
            
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A7);
            output_low(pin_A5);
            output_low(pin_A6);       // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
        while(stop==0){ output_high(pin_A7); output_high(pin_A5); 
                      }
       }
if(v==22){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_high(pin_A0);
            output_low(pin_A1);
            output_low(pin_A2);
            output_high(pin_A4);
            output_high(pin_A3);         
            output_low(pin_A7);
            output_low(pin_A5);
                       
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A4);
            output_low(pin_A3);
            output_low(pin_A6);         // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
          while(stop==0){ output_high(pin_A0); output_high(pin_A4); output_high(pin_A3);   
                        } 
         }
if(v==23){
          while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0);   
            output_high(pin_A1);
            output_low(pin_A2);
            output_high(pin_A7);
            output_high(pin_A5);          
            output_low(pin_A4);
            output_low(pin_A3);
            //delay_ms(400);
            
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A7);
            output_low(pin_A5);
            output_low(pin_A6);           // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            t++;
           }
         while(stop==0){ output_high(pin_A1); output_high(pin_A7); output_high(pin_A5); 
                        }  
         }
         
if(v==24){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0);   
            output_high(pin_A1);
            output_low(pin_A2);
          
            output_high(pin_A4);
            output_high(pin_A3);          
            output_low(pin_A7);
            output_low(pin_A5);
            
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apaga el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
           
            output_low(pin_C0);
            output_low(pin_A4);
            output_low(pin_A3);
            output_low(pin_A6);           // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
            }
          while(stop==0){ output_high(pin_A1); output_high(pin_A4); output_high(pin_A3);
                        }     
         }
 if(v==25){
            while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0);   
            output_low(pin_A1);
            output_high(pin_A2);
            output_high(pin_A7);
            output_high(pin_A5);          
            output_low(pin_A4);
            output_low(pin_A3);
                     
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //  apago el Buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A7);
            output_low(pin_A5);
            output_low(pin_A6);        // apago las luces frontales de alarma
            // delay_ms(750);
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
            }
         while(stop==0){ output_high(pin_A2); output_high(pin_A7); output_high(pin_A5);
                       }   
         }      

if(v==26){
           while((t<=10)&&(stop==0))
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0);   
            output_low(pin_A1);
            output_high(pin_A2);
          
            output_high(pin_A4);
            output_high(pin_A3);          
            output_low(pin_A7);
            output_low(pin_A5);
          
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    //**   apago el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_high(pin_C0);   //**   enciende el Buzzer
            if(t<=5) delay_ms(100);         //**
            delay_ms(100);                  //**
            if(t<=6) output_low(pin_C0);    // apago el buzzer
            if(t>6) delay_ms(450);          //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A4);
            output_low(pin_A3);
            output_low(pin_A6);   // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
            t++;
           }
         while(stop==0){ output_high(pin_A2);
                         output_high(pin_A4);
                         output_high(pin_A3);
                       }   
         } 
 return;        
}
//******************Funcion: apaga el tablero **************************//
void apago_todo()
{
      output_low(pin_A0);   
      output_low(pin_A1);
      output_low(pin_A2);
      output_low(pin_A3);    
      output_low(pin_A4);
      output_low(pin_A5); 
      output_low(pin_A6);    // apaga las luces frontales del tablero
      output_low(pin_A7);
      
  return;    
}

//********  funcion de alarma_2 - eleccion de tarjeta ***************//
void alarma_2(int v2)  
{ int t2;
  
if(v2==1){for(t2=1;t2<=10;t2++)
           {
            output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_high(pin_A0);
            output_low(pin_A1);
            output_low(pin_A2);
            output_high(pin_A7);
            output_low(pin_A5);         
            output_low(pin_A4); 
            output_low(pin_A3);
            
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** // apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //**  // enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_A7);    // apaga tarjeta N1
            output_low(pin_A6);    // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);
           }
         }
 if(v2==2){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_high(pin_A0); 
            output_low(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_high(pin_A5);         
            output_low(pin_A4); 
            output_low(pin_A3);
           
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** // apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //**  // enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);     // apago el buzzer
            output_low(pin_A5);     // apaga tarjeta N2     
            output_low(pin_A6);     // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);        
            }
         }
 if(v2==3){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_high(pin_A0); 
            output_low(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          
            output_high(pin_A4); 
            output_low(pin_A3);
          
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** // apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //**  // enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);   // apago el buzzer
            output_low(pin_A4);   // apaga tarjeta N3
            output_low(pin_A6);   // apago las luces frontales de alarma
            delay_ms(250);
            delay_ms(250);
            delay_ms(250);             
           }
         }
 if(v2==4){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_high(pin_A0); 
            output_low(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          
            output_low(pin_A4); 
            output_high(pin_A3);
          
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** // apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //**  // enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A3);
            output_low(pin_A6);
          
            delay_ms(250);
            delay_ms(250);
            delay_ms(250); 
           }
         }
 if(v2==5){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0);
            output_high(pin_A1);
            output_low(pin_A2);
            output_high(pin_A7);
            output_low(pin_A5);          
            output_low(pin_A4); 
            output_low(pin_A3);
           
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** // apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //**  // enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A7);
            output_low(pin_A6);
            delay_ms(750);
           }
         }        
   if(v2==6){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0);
            output_high(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_high(pin_A5);          
            output_low(pin_A4); 
            output_low(pin_A3);
           
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** // apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //**  // enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A5);
            output_low(pin_A6);
            delay_ms(750);
           }
         }
    if(v2==7){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_high(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          
            output_high(pin_A4); 
            output_low(pin_A3);
           
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** // apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //**  // enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A4);
            output_low(pin_A6);
            delay_ms(750);
           }
         }     
   if(v2==8){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);            // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);  // enciende el Buzzer
            output_low(pin_A0); 
            output_high(pin_A1);
            output_low(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          
            output_low(pin_A4); 
            output_high(pin_A3);
            
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** // apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //**  // enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A3);
            output_low(pin_A6);
            delay_ms(750);
           }
         }      
   if(v2==9){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_low(pin_A1);
            output_high(pin_A2);
            output_high(pin_A7);
            output_low(pin_A5);          
            output_low(pin_A4); 
            output_low(pin_A3);
           
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //** enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A7);
            output_low(pin_A6);
            delay_ms(750);
           }
         }      
    if(v2==10){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_low(pin_A1);
            output_high(pin_A2);
            output_low(pin_A7);
            output_high(pin_A5);          
            output_low(pin_A4); 
            output_low(pin_A3);
          
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //** enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A5);
            output_low(pin_A6);
            delay_ms(750);
           }
         }     
   if(v2==11){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de alarma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_low(pin_A1);
            output_high(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);         
            output_high(pin_A4); 
            output_low(pin_A3);
           
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //** enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0);
            output_low(pin_A4);
            output_low(pin_A6);
            delay_ms(750);
           }
         }      
   if(v2==12){for(t2=1;t2<=10;t2++)
           {output_high(pin_A6);   // enciende las luces frontales de larma
            if(t2<=6) output_high(pin_C0);   // enciende el Buzzer
            output_low(pin_A0); 
            output_low(pin_A1);
            output_high(pin_A2);
            output_low(pin_A7);
            output_low(pin_A5);          //*********** alarma *********
            output_low(pin_A4); 
            output_high(pin_A3);
           
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   //** apago el buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_high(pin_C0);  //** enciende el Buzzer
            if(t2<=5) delay_ms(100);        //**
            delay_ms(100);                  //**
            if(t2<=6) output_low(pin_C0);   // apago el buzzer
            if(t2>6) delay_ms(450);         //** son 3 de 150
            
            output_low(pin_C0); 
            output_low(pin_A3);
            output_low(pin_A6);
            delay_ms(750);
           }
         }      
 return;
}

